pub struct TlsConnector(/* private fields */);Expand description
A wrapper around a native_tls::TlsConnector or rustls::ClientConfig,
providing an async connect method.
Implementations
Sourceimpl TlsConnector
impl TlsConnector
Sourcepub async fn connect<S: Splittable + 'static>(
&self,
domain: &str,
stream: S,
) -> Result<TlsStream<S>>
pub async fn connect<S: Splittable + 'static>( &self, domain: &str, stream: S, ) -> Result<TlsStream<S>>
Connects the provided stream with this connector, assuming the provided domain.
This function will internally call TlsConnector::connect to connect
the stream and returns a future representing the resolution of the
connection operation. The returned future will resolve to either
TlsStream<S> or Error depending if it’s successful or not.
This is typically used for clients who have already established, for example, a TCP connection to a remote server. That stream is then provided here to perform the client half of a connection to a TLS-powered server.
Sourcepub async fn connect_compat<S: Splittable + 'static>(
&self,
domain: &str,
stream: AsyncStream<S>,
) -> Result<TlsStream<S>>
pub async fn connect_compat<S: Splittable + 'static>( &self, domain: &str, stream: AsyncStream<S>, ) -> Result<TlsStream<S>>
Similar to connect but accepts an AsyncStream instead of a raw
stream. Users are free to adjust the inner buffer sizes and limits.